@@ -1,6 +1,7 @@
 package Search::Elasticsearch::Client::1_0::Bulk;
-$Search::Elasticsearch::Client::1_0::Bulk::VERSION = '6.80';
-use Moo;
+$Search::Elasticsearch::Client::1_0::Bulk::VERSION = '6.80_01'; # TRIAL
+
+$Search::Elasticsearch::Client::1_0::Bulk::VERSION = '6.8001';use Moo;
 with 'Search::Elasticsearch::Client::1_0::Role::Bulk',
     'Search::Elasticsearch::Role::Is_Sync';
 use Search::Elasticsearch::Util qw(parse_params throw);
@@ -113,7 +114,7 @@ Search::Elasticsearch::Client::1_0::Bulk - A helper module for the Bulk API and
 
 =head1 VERSION
 
-version 6.80
+version 6.80_01
 
 =head1 SYNOPSIS
 
