@@ -1,6 +1,7 @@
 package Search::Elasticsearch::Client::1_0::TestServer;
-$Search::Elasticsearch::Client::1_0::TestServer::VERSION = '6.80';
-use strict;
+$Search::Elasticsearch::Client::1_0::TestServer::VERSION = '6.80_01'; # TRIAL
+
+$Search::Elasticsearch::Client::1_0::TestServer::VERSION = '6.8001';use strict;
 use warnings;
 
 #===================================
@@ -42,7 +43,7 @@ Search::Elasticsearch::Client::1_0::TestServer - Client-specific backend for Sea
 
 =head1 VERSION
 
-version 6.80
+version 6.80_01
 
 =head1 AUTHOR
 
